@@ -1,7 +1,7 @@
 /*
  * @(#)Barrel.c
  *
- * Copyright 2003 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 2003 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -42,11 +42,12 @@
 #endif
 
 #ifdef WINVER
+#define hasValue(x) (*(x))
 #ifndef LOGPATH
 #define LOGPATH "/usr/tmp"
 #endif
 #ifndef INIFILE
-#define INIFILE "wbarrel.ini"
+#define INIFILE "C:/ProgramData/wpuzzles/wbarrel.ini"
 #endif
 #define SECTION "setup"
 
@@ -63,6 +64,7 @@ static const char *faceColorString[MAX_COLORS] =
 static char faceColorChar[MAX_COLORS] =
 {'G', 'R', 'Y', 'O', 'B', 'b'};
 #else
+#define hasValue(x) (x && *(x))
 #include "picture.h"
 #include "pixmaps/grain_lr.xbm"
 #include "pixmaps/grain_tb.xbm"
@@ -72,7 +74,7 @@ Display *dsp;
 #endif
 
 #ifndef LOGPATH
-#ifdef VMS
+#ifdef __VMS
 #define LOGPATH "SYS$SCRATCH:"
 #else
 #define LOGPATH "/usr/tmp"
@@ -605,7 +607,7 @@ tilePicture(BarrelWidget w, int tile)
 {
 	int face, inc = 0;
 
-	if (!(w->barrel.picture && *(w->barrel.picture)))
+	if (!hasValue(w->barrel.picture))
 		return tile;
 	if (tile < 0)
 		return -1;
@@ -2220,9 +2222,7 @@ void
 destroyPuzzle(BarrelWidget w, HBRUSH brush)
 {
 	if (w->core.memDC) {
-		if (w->barrel.bufferTiles != NULL) {
-			DeleteObject(w->barrel.bufferTiles);
-		}
+		DeleteObject(w->barrel.bufferTiles);
 		DeleteDC(w->core.memDC);
 		w->core.memDC = NULL;
 	}
@@ -2577,7 +2577,7 @@ resizeTiles(BarrelWidget w)
 			DeleteObject(w->barrel.bufferTiles[sel]);
 				w->barrel.bufferTiles[sel] = NULL;
 		}
-		if (!(w->barrel.picture && *(w->barrel.picture))) {
+		if (!hasValue(w->barrel.picture)) {
 			if ((w->barrel.bufferTiles[sel] =
 					CreateCompatibleBitmap(w->core.hDC,
 					w->core.width,
@@ -2608,7 +2608,7 @@ resizeTiles(BarrelWidget w)
 		}
 	}
 #endif
-	if (w->barrel.picture && *(w->barrel.picture)) {
+	if (hasValue(w->barrel.picture)) {
 #ifdef WINVER
 		for (sel = 0; sel < 2; sel++) {
 			w->barrel.bufferTiles[sel] =
@@ -2632,7 +2632,7 @@ resizeTiles(BarrelWidget w)
 #endif
 	}
 #ifndef WINVER
-	if (!(w->barrel.picture && *(w->barrel.picture)) &&
+	if (!hasValue(w->barrel.picture) &&
 			!fixedColors(xgwa.visual, xgwa.depth, w->barrel.install) &&
 			w->barrel.colormap == None) {
 		w->barrel.colormap = XCreateColormap(display, window,
@@ -2643,8 +2643,7 @@ resizeTiles(BarrelWidget w)
 		FILLRECTANGLE(w, w->barrel.bufferTiles[sel],
 			w->barrel.inverseGC,
 			0, 0, w->core.width, w->core.height);
-		if ((w->barrel.picture && *(w->barrel.picture))) {
-
+		if (hasValue(w->barrel.picture)) {
 			(void) XPutImage(display, w->barrel.bufferTiles[sel],
 				w->barrel.inverseGC, w->barrel.image, 0, 0,
 				0, 0,
@@ -2653,7 +2652,7 @@ resizeTiles(BarrelWidget w)
 		}
 	}
 #endif
-	if (!(w->barrel.picture && *(w->barrel.picture))) {
+	if (!hasValue(w->barrel.picture)) {
 		drawAllBufferedTiles(w);
 	} else if (!w->barrel.orient) {
 		setPuzzle(w, ACTION_ORIENTIZE);
