@@ -1501,7 +1501,7 @@ static int
 moveToCenter(BarrelWidget w, int level, int face)
 {
 #if DEBUG
-	printf("moveToCenter level %d, face %d\n", level, face);
+	(void) printf("moveToCenter level %d, face %d\n", level, face);
 #endif
 	/* move to 11 */
 	if (level == 1) {
