@@ -1,7 +1,7 @@
 /*
  * @(#)xbarrel.c
  *
- * Copyright 2003 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 2003 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -140,9 +140,9 @@ static BarrelRec widget;
 
 #ifndef SCOREPATH
 #ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
+#define SCOREPATH "C:/ProgramData/wpuzzles"
 #else
-#define SCOREPATH "c:\\WINDOWS"
+#define SCOREPATH "C:\\ProgramData\\wpuzzles"
 #endif
 #endif
 #define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
@@ -176,8 +176,15 @@ static BarrelRec widget;
 #endif
 #include "pixmaps/64x64/barrel.xbm"
 #define DEFINE_XBM (char *) barrel_64x64_bits, barrel_64x64_width, barrel_64x64_height
+#ifdef HAVE_EDITRES
+#ifdef __VMS
+#include <Xmu/Editres.h>
+#else
+#include <X11/Xmu/Editres.h>
+#endif
+#endif
 #ifndef SCOREPATH
-#ifdef VMS
+#ifdef __VMS
 #define SCOREPATH "SYS$LOGIN:"
 #else
 #define SCOREPATH "/var/games/xpuzzles"
@@ -578,7 +585,7 @@ orientCallback(Widget w, XtPointer clientData,
 		return;
 	if (!orient && picture && *picture) {
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(orientToggle, old, True);
+		setToggle(orientToggle, old, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(orientToggle,
 			XtNstate, old, NULL);
@@ -981,7 +988,7 @@ setSoundCheck(Widget w)
 	XtVaGetValues(puzzle,
 		XtNsound, &sound, NULL);
 #ifdef HAVE_MOTIF
-	XmToggleButtonSetState(w, sound, False);
+	setToggle(w, sound, False);
 #elif defined(HAVE_ATHENA)
 	menuCheck(topLevel, w, sound);
 #endif
@@ -1125,9 +1132,9 @@ Widget w
 	XmScaleSetValue(faceChanger, faces);
 #endif
 #endif
-	XmToggleButtonSetState(orientToggle, orient, True);
-	XmToggleButtonSetState(pairsToggle, pairs, True);
-	XmToggleButtonSetState(practiceToggle, practice, True);
+	setToggle(orientToggle, orient, False);
+	setToggle(pairsToggle, pairs, False);
+	setToggle(practiceToggle, practice, False);
 	{
 		int delay, speed;
 		XtVaGetValues(w,
@@ -1359,7 +1366,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 			XtNpractice, practice,
 			XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(practiceToggle, practice, True);
+		setToggle(practiceToggle, practice, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(practiceToggle,
 			XtNstate, practice, NULL);
@@ -1387,7 +1394,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 		XtVaSetValues(w,
 			XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(orientToggle, orient, True);
+		setToggle(orientToggle, orient, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(orientToggle,
 			XtNstate, orient, NULL);
@@ -1404,7 +1411,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 		XtVaSetValues(w,
 			XtNpairs, pairs, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(pairsToggle, pairs, True);
+		setToggle(pairsToggle, pairs, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(pairsToggle,
 			XtNstate, pairs, NULL);
@@ -2066,7 +2073,14 @@ main(int argc, char **argv)
 	unsigned int i;
 #endif
 
+#ifdef __VMS
+	int n;
+	progDsp = strrchr(argv[0], ']');
+	for (n = 0; progDsp[n] != '\0' && progDsp[n] != '.'; n++);
+	progDsp[n] = '\0';
+#else
 	progDsp = strrchr(argv[0], '/');
+#endif
 	if (progDsp != NULL)
 		progDsp++;
 	if (progDsp == NULL)
@@ -2569,9 +2583,13 @@ main(int argc, char **argv)
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle),
 		XCreateFontCursor(XtDisplay(puzzle), XC_hand2));
+#ifdef HAVE_EDITRES
+	XtAddEventHandler(topLevel, (EventMask) 0, TRUE,
+		(XtEventHandler) _XEditResCheckMessages, NULL);
+#endif
 	XtAppMainLoop(appCon);
 
-#ifdef VMS
+#ifdef __VMS
 	return 1;
 #else
 	return 0;
