@@ -1,7 +1,7 @@
 /*
  * @(#)Bevel.c
  *
- * Copyright 2023  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 2023 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -35,7 +35,7 @@
 #define LOGPATH "/usr/tmp"
 #endif
 #ifndef INIFILE
-#define INIFILE "wbevel.ini"
+#define INIFILE "C:/ProgramData/wpuzzles/wbevel.ini"
 #endif
 
 #define SECTION "setup"
@@ -59,7 +59,7 @@ Display *dsp;
 #endif
 
 #ifndef LOGPATH
-#ifdef VMS
+#ifdef __VMS
 #define LOGPATH "SYS$SCRATCH:"
 #else
 #define LOGPATH "/usr/tmp"
