@@ -1,7 +1,7 @@
 /*
  * @(#)Cubes.c
  *
- * Copyright 1994 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1994 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -42,14 +42,16 @@
 #endif
 
 #ifdef WINVER
+#define hasValue(x) (*(x))
 #ifndef LOGPATH
 #define LOGPATH "/usr/tmp"
 #endif
 #ifndef INIFILE
-#define INIFILE "wcubes.ini"
+#define INIFILE "C:/ProgramData/wpuzzles/wcubes.ini"
 #endif
 #define SECTION "setup"
 #else
+#define hasValue(x) (x && *(x))
 #include "picture.h"
 #include "pixmaps/grain_lr.xbm"
 #include "pixmaps/grain_tb.xbm"
@@ -59,7 +61,7 @@ Display *dsp;
 #endif
 
 #ifndef LOGPATH
-#ifdef VMS
+#ifdef __VMS
 #define LOGPATH "SYS$SCRATCH:"
 #else
 #define LOGPATH "/usr/tmp"
@@ -1037,7 +1039,7 @@ animateMove(CubesWidget w, int fromPos, int fast)
 				w->cubes.inverseGC[2],
 				xR, yR + hR - incAt, wR, incAt);
 		}
-		if (!(w->cubes.picture && *(w->cubes.picture))) {
+		if (!hasValue(w->cubes.picture)) {
 			drawBlockFrame(w, xR, yR, wR, hR, incAt);
 		}
 		/* end disappear block */
@@ -1049,7 +1051,7 @@ animateMove(CubesWidget w, int fromPos, int fast)
 				yToCenter - inc,
 				2 * (inc + w->cubes.blockSize.x / 2 - w->cubes.blockSize.y / 2),
 				2 * inc);
-		if (!(w->cubes.picture && *(w->cubes.picture))) {
+		if (!hasValue(w->cubes.picture)) {
 			drawBlockFrame(w,
 				xToCenter - inc - (w->cubes.blockSize.x / 2 - w->cubes.blockSize.y / 2) + dx - incAt,
 				yToCenter - inc + dy - incAt,
@@ -1074,7 +1076,7 @@ animateMove(CubesWidget w, int fromPos, int fast)
 				yToCenter - inc - (w->cubes.blockSize.y / 2 - w->cubes.blockSize.x / 2),
 				2 * inc,
 				2 * (inc + w->cubes.blockSize.y / 2 - w->cubes.blockSize.x / 2));
-		if (!(w->cubes.picture && *(w->cubes.picture))) {
+		if (!hasValue(w->cubes.picture)) {
 			drawBlockFrame(w,
 				xToCenter - inc + dx - incAt,
 				yToCenter - inc - (w->cubes.blockSize.y / 2 - w->cubes.blockSize.x / 2) + dy - incAt,
@@ -2257,9 +2259,7 @@ void
 destroyPuzzle(CubesWidget w, HBRUSH brush)
 {
 	if (w->core.memDC) {
-		if (w->cubes.bufferBlocks != NULL) {
-			DeleteObject(w->cubes.bufferBlocks);
-		}
+		DeleteObject(w->cubes.bufferBlocks);
 		DeleteDC(w->core.memDC);
 		w->core.memDC = NULL;
 	}
@@ -2568,7 +2568,7 @@ resizeBlocks(CubesWidget w)
 			DeleteObject(w->cubes.bufferBlocks[sel]);
 				w->cubes.bufferBlocks[sel] = NULL;
 		}
-		if (!(w->cubes.picture && *(w->cubes.picture))) {
+		if (!hasValue(w->cubes.picture)) {
 			if ((w->cubes.bufferBlocks[sel] =
 					CreateCompatibleBitmap(w->core.hDC,
 					w->core.width,
@@ -2599,7 +2599,7 @@ resizeBlocks(CubesWidget w)
 		}
 	}
 #endif
-	if (w->cubes.picture && *(w->cubes.picture)) {
+	if (hasValue(w->cubes.picture)) {
 #ifdef WINVER
 		for (sel = 0; sel < 2; sel++) {
 			w->cubes.bufferBlocks[sel] =
@@ -2623,7 +2623,7 @@ resizeBlocks(CubesWidget w)
 #endif
 	}
 #ifndef WINVER
-	if (!(w->cubes.picture && *(w->cubes.picture)) &&
+	if (!hasValue(w->cubes.picture) &&
 			!fixedColors(xgwa.visual, xgwa.depth, w->cubes.install) &&
 			w->cubes.colormap == None) {
 		w->cubes.colormap = XCreateColormap(display, window,
@@ -2634,8 +2634,7 @@ resizeBlocks(CubesWidget w)
 		FILLRECTANGLE(w, w->cubes.bufferBlocks[sel],
 			w->cubes.inverseGC[2],
 			0, 0, w->core.width, w->core.height);
-		if ((w->cubes.picture && *(w->cubes.picture))) {
-
+		if (hasValue(w->cubes.picture)) {
 			(void) XPutImage(display, w->cubes.bufferBlocks[sel],
 				w->cubes.inverseGC[2], w->cubes.image, 0, 0,
 				0, 0,
@@ -2644,7 +2643,7 @@ resizeBlocks(CubesWidget w)
 		}
 	}
 #endif
-	if (!(w->cubes.picture && *(w->cubes.picture))) {
+	if (!hasValue(w->cubes.picture)) {
 		drawAllBufferedBlocks(w);
 	}
 }
