@@ -1,7 +1,7 @@
 /*
  * @(#)xdino.c
  *
- * Copyright 1995 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1995 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -152,9 +152,9 @@ static DinoRec widget;
 
 #ifndef SCOREPATH
 #ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
+#define SCOREPATH "C:/ProgramData/wpuzzles"
 #else
-#define SCOREPATH "c:\\WINDOWS"
+#define SCOREPATH "C:\\ProgramData\\wpuzzles"
 #endif
 #endif
 #define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
@@ -194,8 +194,15 @@ static DinoRec widget;
 #endif
 #include "pixmaps/64x64/dino.xbm"
 #define DEFINE_XBM (char *) dino_64x64_bits, dino_64x64_width, dino_64x64_height
+#ifdef HAVE_EDITRES
+#ifdef __VMS
+#include <Xmu/Editres.h>
+#else
+#include <X11/Xmu/Editres.h>
+#endif
+#endif
 #ifndef SCOREPATH
-#ifdef VMS
+#ifdef __VMS
 #define SCOREPATH "SYS$LOGIN:"
 #else
 #define SCOREPATH "/var/games/xpuzzles"
@@ -928,7 +935,7 @@ setSoundCheck(Widget w)
 	XtVaGetValues(puzzle2d,
 		XtNsound, &sound, NULL);
 #ifdef HAVE_MOTIF
-	XmToggleButtonSetState(w, sound, False);
+	setToggle(w, sound, False);
 #elif defined(HAVE_ATHENA)
 	menuCheck(topLevel, w, sound);
 #endif
@@ -1031,9 +1038,9 @@ void
 	makeEquivalent(&userName, &scoreFile, &mode,
 		&orient, &practice, &delay);
 #ifdef HAVE_MOTIF
-	XmToggleButtonSetState(modeRadio[mode - PERIOD2], True, False);
-	XmToggleButtonSetState(orientToggle, orient, True);
-	XmToggleButtonSetState(practiceToggle, practice, True);
+	setToggle(modeRadio[mode - PERIOD2], True, True);
+	setToggle(orientToggle, orient, False);
+	setToggle(practiceToggle, practice, False);
 	{
 		int speed;
 		speed = getSpeed(delay);
@@ -1322,7 +1329,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 			XtNpractice, practice,
 			XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(practiceToggle, practice, True);
+		setToggle(practiceToggle, practice, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(practiceToggle,
 			XtNstate, practice, NULL);
@@ -1377,7 +1384,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 		XtVaSetValues(otherw,
 			XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(orientToggle, orient, True);
+		setToggle(orientToggle, orient, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(orientToggle,
 			XtNstate, orient, NULL);
@@ -1398,7 +1405,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 		XtVaSetValues(otherw,
 			XtNmode, mode, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(modeRadio[mode - PERIOD2], True, True);
+		setToggle(modeRadio[mode - PERIOD2], True, True);
 #elif defined(HAVE_ATHENA)
 #ifdef USE_POPUP
 		max = findMaxLength((char **) modeStrings,
@@ -2073,7 +2080,14 @@ main(int argc, char **argv)
 	char titleDsp[TITLE_FILE_LENGTH];
 #endif
 
+#ifdef __VMS
+	int n;
+	progDsp = strrchr(argv[0], ']');
+	for (n = 0; progDsp[n] != '\0' && progDsp[n] != '.'; n++);
+	progDsp[n] = '\0';
+#else
 	progDsp = strrchr(argv[0], '/');
+#endif
 	if (progDsp != NULL)
 		progDsp++;
 	if (progDsp == NULL)
@@ -2580,9 +2594,13 @@ main(int argc, char **argv)
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle3d),
 		XCreateFontCursor(XtDisplay(puzzle3d), XC_hand2));
+#ifdef HAVE_EDITRES
+	XtAddEventHandler(topLevel, (EventMask) 0, TRUE,
+		(XtEventHandler) _XEditResCheckMessages, NULL);
+#endif
 	XtAppMainLoop(appCon);
 
-#ifdef VMS
+#ifdef __VMS
 	return 1;
 #else
 	return 0;
