@@ -891,11 +891,11 @@ solveSomeTiles(HexagonsWidget w) {
 		for (loc2 = 0; loc2 < w->hexagons.sizeSize; loc2++) {
 			row2 = toRow(w, loc2);
 			min = DIST(w, loc1, row1, loc2, row2);
-			printf("  %d, min %d\n", loc2, min);
+			(void) printf("  %d, min %d\n", loc2, min);
 		}
 	}*/
 	for (loc1 = 0; loc1 < w->hexagons.sizeSize; loc1++) {
-		printf("%d:  %d %d %d %d %d %d\n", loc1,
+		(void) printf("%d:  %d %d %d %d %d %d\n", loc1,
 			nextRightUp(loc1),
 			nextRight(loc1),
 			nextRightDown(loc1),
