@@ -1,7 +1,7 @@
 /*
  * @(#)xmball.c
  *
- * Copyright 1994 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1994 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -163,9 +163,9 @@ static MballRec widget;
 
 #ifndef SCOREPATH
 #ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
+#define SCOREPATH "C:/ProgramData/wpuzzles"
 #else
-#define SCOREPATH "c:\\WINDOWS"
+#define SCOREPATH "C:\\ProgramData\\wpuzzles"
 #endif
 #endif
 #define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
@@ -203,8 +203,15 @@ static MballRec widget;
 #endif
 #include "pixmaps/64x64/mball.xbm"
 #define DEFINE_XBM (char *) mball_64x64_bits, mball_64x64_width, mball_64x64_height
+#ifdef HAVE_EDITRES
+#ifdef __VMS
+#include <Xmu/Editres.h>
+#else
+#include <X11/Xmu/Editres.h>
+#endif
+#endif
 #ifndef SCOREPATH
-#ifdef VMS
+#ifdef __VMS
 #define SCOREPATH "SYS$LOGIN:"
 #else
 #define SCOREPATH "/var/games/xpuzzles"
@@ -255,12 +262,12 @@ static const char *wedgeStrings[] =
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
 #ifdef HAVE_MOTIF
-static Widget wedgeChoices[(MAX_WEDGES - MIN_WEDGES) / 2 + 1];
+static Widget wedgeRadio[(MAX_WEDGES - MIN_WEDGES) / 2 + 1];
 static Widget bandChanger, speedChanger;
 #elif defined(HAVE_ATHENA)
 static Widget wedgeLabel = None;
 #ifndef USE_POPUP
-static Widget wedgeChoices[(MAX_WEDGES - MIN_WEDGES) / 2 + 1];
+static Widget wedgeRadio[(MAX_WEDGES - MIN_WEDGES) / 2 + 1];
 #endif
 static Widget bandSlider, speedSlider;
 static Widget bandSliderLabel, speedSliderLabel;
@@ -814,7 +821,6 @@ wedgeCallback(Widget w,
 		return;
 #ifdef HAVE_ATHENA
 	if (wedgeLabel) {
-printf("defaultString [%s]\n", wedgeStrings[position]);
 		XtVaSetValues(wedgeLabel,
 			XtNlabel, wedgeStrings[position], NULL);
 	}
@@ -1085,7 +1091,7 @@ setSoundCheck(Widget w)
 	XtVaGetValues(puzzle2d,
 		XtNsound, &sound, NULL);
 #ifdef HAVE_MOTIF
-	XmToggleButtonSetState(w, sound, False);
+	setToggle(w, sound, False);
 #elif defined(HAVE_ATHENA)
 	menuCheck(topLevel, w, sound);
 #endif
@@ -1098,7 +1104,7 @@ setPerspectiveCheck(Widget w)
 	XtVaGetValues(puzzle2d,
 		XtNperspective, &perspective, NULL);
 #ifdef HAVE_MOTIF
-	XmToggleButtonSetState(w, perspective, False);
+	setToggle(w, perspective, False);
 #elif defined(HAVE_ATHENA)
 	menuCheck(topLevel, w, perspective);
 #endif
@@ -1224,10 +1230,9 @@ Widget w
 			XmNmaximum, bands, NULL);
 	XmScaleSetValue(bandChanger, bands);
 #endif
-	XmToggleButtonSetState(wedgeChoices[(wedges - MIN_WEDGES) / 2],
-		True, False);
-	XmToggleButtonSetState(orientToggle, orient, True);
-	XmToggleButtonSetState(practiceToggle, practice, True);
+	setToggle(wedgeRadio[(wedges - MIN_WEDGES) / 2], True, True);
+	setToggle(orientToggle, orient, False);
+	setToggle(practiceToggle, practice, False);
 	{
 		int delay, speed;
 		XtVaGetValues(w,
@@ -1545,7 +1550,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 				XtNpractice, practice,
 				XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(practiceToggle, practice, True);
+		setToggle(practiceToggle, practice, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(practiceToggle,
 			XtNstate, practice, NULL);
@@ -1670,7 +1675,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 			XtVaSetValues(otherw,
 				XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(orientToggle, orient, True);
+		setToggle(orientToggle, orient, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(orientToggle,
 			XtNstate, orient, NULL);
@@ -1691,7 +1696,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 		w->mball.wedges = wedges;
 #else
 #if defined(HAVE_ATHENA) && !defined(USE_POPUP)
-		XtVaSetValues(wedgeChoices[wedgesIndex],
+		XtVaSetValues(wedgeRadio[wedgesIndex],
 			XtNstate, True, NULL);
 #endif
 		XtVaSetValues(w,
@@ -1700,7 +1705,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 			XtVaSetValues(otherw,
 				XtNwedges, wedges, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(wedgeChoices[wedgesIndex], True, True);
+		setToggle(wedgeRadio[wedgesIndex], True, True);
 #elif defined(HAVE_ATHENA) && defined(USE_POPUP)
 		max = findMaxLength((char **) wedgeStrings,
 			sizeof(wedgeStrings) / sizeof(*wedgeStrings));
@@ -2388,7 +2393,14 @@ main(int argc, char **argv)
 	char titleDsp[TITLE_FILE_LENGTH];
 #endif
 
+#ifdef __VMS
+	int n;
+	progDsp = strrchr(argv[0], ']');
+	for (n = 0; progDsp[n] != '\0' && progDsp[n] != '.'; n++);
+	progDsp[n] = '\0';
+#else
 	progDsp = strrchr(argv[0], '/');
+#endif
 	if (progDsp != NULL)
 		progDsp++;
 	if (progDsp == NULL)
@@ -2591,7 +2603,7 @@ main(int argc, char **argv)
 	labelRowCol = XtVaCreateManagedWidget("labelRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNorientation, XmHORIZONTAL, NULL);
-	createRadio(labelRowCol, (Widget **) &wedgeChoices[0],
+	createRadio(labelRowCol, (Widget **) &wedgeRadio[0],
 		wedgeStrings, wedgesLabel, XtNumber(wedgeStrings),
 		(XtCallbackProc) wedgeCallback);
 	bandsRowCol = XtVaCreateManagedWidget("bandsRowCol",
@@ -2801,7 +2813,7 @@ main(int argc, char **argv)
 		sizeof(wedgeStrings) / sizeof(*wedgeStrings),
 		(XtCallbackProc) wedgeCallback);
 #else
-	createRadio(wedgeBox, (Widget **) &wedgeChoices[0], wedgeStrings,
+	createRadio(wedgeBox, (Widget **) &wedgeRadio[0], wedgeStrings,
 		wedgesLabel, 0, (wedges - MIN_WEDGES) / 2,
 		sizeof(wedgeStrings) / sizeof(*wedgeStrings),
 		(XtCallbackProc) wedgeCallback);
@@ -2924,9 +2936,13 @@ main(int argc, char **argv)
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle2d),
 		XCreateFontCursor(XtDisplay(puzzle2d), XC_hand2));
+#ifdef HAVE_EDITRES
+	XtAddEventHandler(topLevel, (EventMask) 0, TRUE,
+		(XtEventHandler) _XEditResCheckMessages, NULL);
+#endif
 	XtAppMainLoop(appCon);
 
-#ifdef VMS
+#ifdef __VMS
 	return 1;
 #else
 	return 0;
