@@ -1,7 +1,7 @@
 /*
  * @(#)Mlink.c
  *
- * Copyright 1994 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1994 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -42,11 +42,12 @@
 #endif
 
 #ifdef WINVER
+#define hasValue(x) (*(x))
 #ifndef LOGPATH
 #define LOGPATH "/usr/tmp"
 #endif
 #ifndef INIFILE
-#define INIFILE "wmlink.ini"
+#define INIFILE "C:/ProgramData/wpuzzles/wmlink.ini"
 #endif
 #define SECTION "setup"
 
@@ -65,6 +66,7 @@ static const char *faceColorString[MAX_FACES] =
 static char faceColorChar[MAX_FACES] =
 {'W', 'Y', 'G', 'R', 'B', 'M', 'C', 'O'};
 #else
+#define hasValue(x) (x && *(x))
 #include "picture.h"
 #include "pixmaps/grain_lr.xbm"
 #include "pixmaps/grain_tb.xbm"
@@ -74,7 +76,7 @@ Display *dsp;
 #endif
 
 #ifndef LOGPATH
-#ifdef VMS
+#ifdef __VMS
 #define LOGPATH "SYS$SCRATCH:"
 #else
 #define LOGPATH "/usr/tmp"
@@ -2293,9 +2295,7 @@ void
 destroyPuzzle(MlinkWidget w, HBRUSH brush)
 {
 	if (w->core.memDC) {
-		if (w->mlink.bufferTiles != NULL) {
-			DeleteObject(w->mlink.bufferTiles);
-		}
+		DeleteObject(w->mlink.bufferTiles);
 		DeleteDC(w->core.memDC);
 		w->core.memDC = NULL;
 	}
@@ -2652,7 +2652,7 @@ resizeTiles(MlinkWidget w)
 			DeleteObject(w->mlink.bufferTiles[sel]);
 				w->mlink.bufferTiles[sel] = NULL;
 		}
-		if (!(w->mlink.picture && *(w->mlink.picture))) {
+		if (!hasValue(w->mlink.picture)) {
 			if ((w->mlink.bufferTiles[sel] =
 					CreateCompatibleBitmap(w->core.hDC,
 					w->core.width,
@@ -2683,7 +2683,7 @@ resizeTiles(MlinkWidget w)
 		}
 	}
 #endif
-	if (w->mlink.picture && *(w->mlink.picture)) {
+	if (hasValue(w->mlink.picture)) {
 #ifdef WINVER
 		for (sel = 0; sel < 2; sel++) {
 			w->mlink.bufferTiles[sel] =
@@ -2707,7 +2707,7 @@ resizeTiles(MlinkWidget w)
 #endif
 	}
 #ifndef WINVER
-	if (!(w->mlink.picture && *(w->mlink.picture)) &&
+	if (!hasValue(w->mlink.picture) &&
 			!fixedColors(xgwa.visual, xgwa.depth, w->mlink.install) &&
 			w->mlink.colormap == None) {
 		w->mlink.colormap = XCreateColormap(display, window,
@@ -2718,8 +2718,7 @@ resizeTiles(MlinkWidget w)
 		FILLRECTANGLE(w, w->mlink.bufferTiles[sel],
 			w->mlink.inverseGC,
 			0, 0, w->core.width, w->core.height);
-		if ((w->mlink.picture && *(w->mlink.picture))) {
-
+		if (hasValue(w->mlink.picture)) {
 			(void) XPutImage(display, w->mlink.bufferTiles[sel],
 				w->mlink.inverseGC, w->mlink.image, 0, 0,
 				0, 0,
@@ -2728,7 +2727,7 @@ resizeTiles(MlinkWidget w)
 		}
 	}
 #endif
-	if (!(w->mlink.picture && *(w->mlink.picture))) {
+	if (!hasValue(w->mlink.picture)) {
 		drawAllBufferedTiles(w);
 	} else if (!w->mlink.orient) {
 		setPuzzle(w, ACTION_ORIENTIZE);
