@@ -30,7 +30,7 @@
 #define LOGPATH "/usr/tmp"
 #endif
 #ifndef INIFILE
-#define INIFILE "wpanex.ini"
+#define INIFILE "C:/ProgramData/wpuzzles/wpanex.ini"
 #endif
 
 #define SECTION "setup"
@@ -51,7 +51,7 @@ Display *dsp;
 #endif
 
 #ifndef LOGPATH
-#ifdef VMS
+#ifdef __VMS
 #define LOGPATH "SYS$SCRATCH:"
 #else
 #define LOGPATH "/usr/tmp"
@@ -470,7 +470,7 @@ printStacks(PanexWidget w)
 	(void) printf("top: where are the tiles in the stack\n");
 	for (position = 0; position < w->panex.tiles + w->panex.blanks; position++)
 		for (stack = 0; stack < MAX_STACKS; stack++) {
-			printf("%d,%d", w->panex.tileOfPosition[stack][position].stack,
+			(void) printf("%d,%d", w->panex.tileOfPosition[stack][position].stack,
 				w->panex.tileOfPosition[stack][position].loc);
 			if (stack == MAX_STACKS - 1)
 				(void) printf("\n");
@@ -487,7 +487,7 @@ printTiles(PanexWidget w)
 	(void) printf("pot: which stack are the tiles in\n");
 	for (position = 0; position < w->panex.tiles; position++)
 		for (stack = 0; stack < w->panex.stacks; stack++) {
-			printf("%d,%d", w->panex.positionOfTile[stack][position].stack,
+			(void) printf("%d,%d", w->panex.positionOfTile[stack][position].stack,
 				w->panex.positionOfTile[stack][position].loc);
 			if (stack == w->panex.stacks - 1)
 				(void) printf("\n");
@@ -933,7 +933,7 @@ drawSlots(PanexWidget w, Pixmap dr)
 		w->panex.delta.y;
 	dy = w->panex.delta.y / 2 + w->panex.puzzleOffset.y + sizey;
 	FILLRECTANGLE(w, dr, w->panex.inverseGC[4],
-		((algorithme) ? 0 : dx), dy,
+		((algorithme) ? w->panex.frameThickness : dx), dy,
 		((algorithme) ? w->panex.width :
 			(sizex + (MAX_STACKS - 1) * w->panex.pos.x)),
 		sizey);
