@@ -1,7 +1,7 @@
 /*
  * @(#)xpanex.c
  *
- * Copyright 1996 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1996 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -155,9 +155,9 @@ static PanexRec widget;
 
 #ifndef SCOREPATH
 #ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
+#define SCOREPATH "C:/ProgramData/wpuzzles"
 #else
-#define SCOREPATH "c:\\WINDOWS"
+#define SCOREPATH "C:\\ProgramData\\wpuzzles"
 #endif
 #endif
 #define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
@@ -191,8 +191,15 @@ static PanexRec widget;
 #endif
 #include "pixmaps/64x64/panex.xbm"
 #define DEFINE_XBM (char *) panex_64x64_bits, panex_64x64_width, panex_64x64_height
+#ifdef HAVE_EDITRES
+#ifdef __VMS
+#include <Xmu/Editres.h>
+#else
+#include <X11/Xmu/Editres.h>
+#endif
+#endif
 #ifndef SCOREPATH
-#ifdef VMS
+#ifdef __VMS
 #define SCOREPATH "SYS$LOGIN:"
 #else
 #define SCOREPATH "/var/games/xpuzzles"
@@ -810,7 +817,7 @@ setSoundCheck(Widget w)
 	XtVaGetValues(puzzle,
 		XtNsound, &sound, NULL);
 #ifdef HAVE_MOTIF
-	XmToggleButtonSetState(w, sound, False);
+	setToggle(w, sound, False);
 #elif defined(HAVE_ATHENA)
 	menuCheck(topLevel, w, sound);
 #endif
@@ -945,7 +952,7 @@ Widget w
 			XmNmaximum, tiles, NULL);
 	XmScaleSetValue(tileChanger, tiles);
 #endif
-	XmToggleButtonSetState(modeRadio[mode - HANOI], True, False);
+	setToggle(modeRadio[mode - HANOI], True, True);
 	{
 		int delay, speed;
 		XtVaGetValues(puzzle,
@@ -1186,8 +1193,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 		XtVaSetValues(w,
 			XtNmode, mode, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(modeRadio[mode - HANOI], True,
-			True);
+		setToggle(modeRadio[mode - HANOI], True, True);
 #elif defined(HAVE_ATHENA)
 #ifdef USE_POPUP
 		max = findMaxLength((char **) modeStrings,
@@ -1599,7 +1605,14 @@ main(int argc, char **argv)
 	unsigned int i;
 #endif
 
+#ifdef __VMS
+	int n;
+	progDsp = strrchr(argv[0], ']');
+	for (n = 0; progDsp[n] != '\0' && progDsp[n] != '.'; n++);
+	progDsp[n] = '\0';
+#else
 	progDsp = strrchr(argv[0], '/');
+#endif
 	if (progDsp != NULL)
 		progDsp++;
 	if (progDsp == NULL)
@@ -2019,9 +2032,13 @@ main(int argc, char **argv)
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle),
 		XCreateFontCursor(XtDisplay(puzzle), XC_hand2));
+#ifdef HAVE_EDITRES
+	XtAddEventHandler(topLevel, (EventMask) 0, TRUE,
+		(XtEventHandler) _XEditResCheckMessages, NULL);
+#endif
 	XtAppMainLoop(appCon);
 
-#ifdef VMS
+#ifdef __VMS
 	return 1;
 #else
 	return 0;
