@@ -1,7 +1,7 @@
 /*
  * @(#)Pyraminx.c
  *
- * Copyright 1994 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1994 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -34,7 +34,7 @@
 #define LOGPATH "/usr/tmp"
 #endif
 #ifndef INIFILE
-#define INIFILE "wpyraminx.ini"
+#define INIFILE "C:/ProgramData/wpuzzles/wpyraminx.ini"
 #endif
 
 #define SECTION "setup"
@@ -56,7 +56,7 @@ Display *dsp;
 #endif
 
 #ifndef LOGPATH
-#ifdef VMS
+#ifdef __VMS
 #define LOGPATH "SYS$SCRATCH:"
 #else
 #define LOGPATH "/usr/tmp"
