@@ -1,7 +1,7 @@
 /*
  * @(#)xpyraminx.c
  *
- * Copyright 1993 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1993 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -193,9 +193,9 @@ static PyraminxRec widget;
 
 #ifndef SCOREPATH
 #ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
+#define SCOREPATH "C:/ProgramData/wpuzzles"
 #else
-#define SCOREPATH "c:\\WINDOWS"
+#define SCOREPATH "C:\\ProgramData\\wpuzzles"
 #endif
 #endif
 #define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
@@ -233,8 +233,15 @@ static PyraminxRec widget;
 #endif
 #include "pixmaps/64x64/pyraminx.xbm"
 #define DEFINE_XBM (char *) pyraminx_64x64_bits, pyraminx_64x64_width, pyraminx_64x64_height
+#ifdef HAVE_EDITRES
+#ifdef __VMS
+#include <Xmu/Editres.h>
+#else
+#include <X11/Xmu/Editres.h>
+#endif
+#endif
 #ifndef SCOREPATH
-#ifdef VMS
+#ifdef __VMS
 #define SCOREPATH "SYS$LOGIN:"
 #else
 #define SCOREPATH "/var/games/xpuzzles"
@@ -1204,7 +1211,7 @@ setSoundCheck(Widget w)
 	XtVaGetValues(puzzle2d,
 		XtNsound, &sound, NULL);
 #ifdef HAVE_MOTIF
-	XmToggleButtonSetState(w, sound, False);
+	setToggle(w, sound, False);
 #elif defined(HAVE_ATHENA)
 	menuCheck(topLevel, w, sound);
 #endif
@@ -1330,10 +1337,10 @@ Widget w
 			XmNmaximum, size, NULL);
 	XmScaleSetValue(facetChanger, size);
 #endif
-	XmToggleButtonSetState(modeRadio[mode - PERIOD2], True, False);
-	XmToggleButtonSetState(orientToggle, orient, True);
-	XmToggleButtonSetState(stickyToggle, sticky, True);
-	XmToggleButtonSetState(practiceToggle, practice, True);
+	setToggle(modeRadio[mode - PERIOD2], True, True);
+	setToggle(orientToggle, orient, False);
+	setToggle(stickyToggle, sticky, False);
+	setToggle(practiceToggle, practice, False);
 	{
 		int speed;
 		speed = getSpeed(delay);
@@ -1650,7 +1657,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 				XtNpractice, practice,
 				XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(practiceToggle, practice, True);
+		setToggle(practiceToggle, practice, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(practiceToggle,
 			XtNstate, practice, NULL);
@@ -1781,7 +1788,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 			XtVaSetValues(otherw,
 				XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(orientToggle, orient, True);
+		setToggle(orientToggle, orient, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(orientToggle,
 			XtNstate, orient, NULL);
@@ -1803,7 +1810,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 			XtVaSetValues(otherw,
 				XtNmode, mode, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(modeRadio[mode - PERIOD2], True, True);
+		setToggle(modeRadio[mode - PERIOD2], True, True);
 #elif defined(HAVE_ATHENA)
 #ifdef USE_POPUP
 		max = findMaxLength((char **) modeStrings,
@@ -1839,7 +1846,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 				XtNsticky, sticky,
 				XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(stickyToggle, sticky, True);
+		setToggle(stickyToggle, sticky, False);
 #ifdef USE_SPIN
 		XtVaSetValues(facetChanger,
 			XmNposition, size, NULL);
@@ -2529,7 +2536,14 @@ main(int argc, char **argv)
 	char titleDsp[TITLE_FILE_LENGTH];
 #endif
 
+#ifdef __VMS
+	int n;
+	progDsp = strrchr(argv[0], ']');
+	for (n = 0; progDsp[n] != '\0' && progDsp[n] != '.'; n++);
+	progDsp[n] = '\0';
+#else
 	progDsp = strrchr(argv[0], '/');
+#endif
 	if (progDsp != NULL)
 		progDsp++;
 	if (progDsp == NULL)
@@ -3077,9 +3091,13 @@ main(int argc, char **argv)
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle2d),
 		XCreateFontCursor(XtDisplay(puzzle2d), XC_hand2));
+#ifdef HAVE_EDITRES
+	XtAddEventHandler(topLevel, (EventMask) 0, TRUE,
+		(XtEventHandler) _XEditResCheckMessages, NULL);
+#endif
 	XtAppMainLoop(appCon);
 
-#ifdef VMS
+#ifdef __VMS
 	return 1;
 #else
 	return 0;
