@@ -1,7 +1,7 @@
 /*
  * @(#)xrubik.c
  *
- * Copyright 1993 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1993 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -184,9 +184,9 @@ static RubikRec widget;
 
 #ifndef SCOREPATH
 #ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
+#define SCOREPATH "C:/ProgramData/wpuzzles"
 #else
-#define SCOREPATH "c:\\WINDOWS"
+#define SCOREPATH "C:\\ProgramData\\wpuzzles"
 #endif
 #endif
 #define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
@@ -226,8 +226,15 @@ static RubikRec widget;
 #endif
 #include "pixmaps/64x64/rubik.xbm"
 #define DEFINE_XBM (char *) rubik_64x64_bits, rubik_64x64_width, rubik_64x64_height
+#ifdef HAVE_EDITRES
+#ifdef __VMS
+#include <Xmu/Editres.h>
+#else
+#include <X11/Xmu/Editres.h>
+#endif
+#endif
 #ifndef SCOREPATH
-#ifdef VMS
+#ifdef __VMS
 #define SCOREPATH "SYS$LOGIN:"
 #else
 #define SCOREPATH "/var/games/xpuzzles"
@@ -1262,7 +1269,7 @@ setSoundCheck(Widget w)
 	XtVaGetValues(puzzle2d,
 		XtNsound, &sound, NULL);
 #ifdef HAVE_MOTIF
-	XmToggleButtonSetState(w, sound, False);
+	setToggle(w, sound, False);
 #elif defined(HAVE_ATHENA)
 	menuCheck(topLevel, w, sound);
 #endif
@@ -1412,8 +1419,8 @@ void
 			XmNmaximum, sizeZ, NULL);
 	XmScaleSetValue(facetZChanger, sizeZ);
 #endif
-	XmToggleButtonSetState(orientToggle, orient, True);
-	XmToggleButtonSetState(practiceToggle, practice, True);
+	setToggle(orientToggle, orient, False);
+	setToggle(practiceToggle, practice, False);
 	{
 		int speed;
 		speed = getSpeed(delay);
@@ -1721,7 +1728,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 			XtNpractice, practice,
 			XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(practiceToggle, practice, True);
+		setToggle(practiceToggle, practice, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(practiceToggle,
 			XtNstate, practice, NULL);
@@ -1776,7 +1783,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 		XtVaSetValues(otherw,
 			XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(orientToggle, orient, True);
+		setToggle(orientToggle, orient, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(orientToggle,
 			XtNstate, orient, NULL);
@@ -2628,7 +2635,14 @@ main(int argc, char **argv)
 	char titleDsp[TITLE_FILE_LENGTH];
 #endif
 
+#ifdef __VMS
+	int n;
+	progDsp = strrchr(argv[0], ']');
+	for (n = 0; progDsp[n] != '\0' && progDsp[n] != '.'; n++);
+	progDsp[n] = '\0';
+#else
 	progDsp = strrchr(argv[0], '/');
+#endif
 	if (progDsp != NULL)
 		progDsp++;
 	if (progDsp == NULL)
@@ -3216,9 +3230,13 @@ main(int argc, char **argv)
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle3d),
 		XCreateFontCursor(XtDisplay(puzzle3d), XC_hand2));
+#ifdef HAVE_EDITRES
+	XtAddEventHandler(topLevel, (EventMask) 0, TRUE,
+		(XtEventHandler) _XEditResCheckMessages, NULL);
+#endif
 	XtAppMainLoop(appCon);
 
-#ifdef VMS
+#ifdef __VMS
 	return 1;
 #else
 	return 0;
