@@ -35,7 +35,7 @@
 #define LOGPATH "/usr/tmp"
 #endif
 #ifndef INIFILE
-#define INIFILE "wskewb.ini"
+#define INIFILE "C:/ProgramData/wpuzzles/wskewb.ini"
 #endif
 
 #define SECTION "setup"
@@ -59,7 +59,7 @@ Display *dsp;
 #endif
 
 #ifndef LOGPATH
-#ifdef VMS
+#ifdef __VMS
 #define LOGPATH "SYS$SCRATCH:"
 #else
 #define LOGPATH "/usr/tmp"
