@@ -910,10 +910,10 @@ setRemainingCorners(SkewbWidget w)
 	f[3] = w->skewb.cubeLoc[2][3].face;
 #ifdef DEBUG
 	(void) printf("remainingCorners face 5");
-	printf(": 5 %d", f[0]);
-	printf(", 4 %d", f[1]);
-	printf(", 0 %d", f[2]);
-	printf(", 1 %d\n", f[3]);
+	(void) printf(": 5 %d", f[0]);
+	(void) printf(", 4 %d", f[1]);
+	(void) printf(", 0 %d", f[2]);
+	(void) printf(", 1 %d\n", f[3]);
 #endif
 	if (f[0] == 5)
 		r[0] = 0;
