@@ -1,7 +1,7 @@
 /*
  * @(#)Threed.c
  *
- * Copyright 1994 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1994 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -26,10 +26,7 @@
 
 #ifdef WINVER
 #ifndef INIFILE
-#define INIFILE "wthreed.ini"
-#endif
-#ifndef DATAFILE
-#define DATAFILE "c:\\Windows\threed.dat"
+#define INIFILE "C:/ProgramData/wthreed/wthreed.ini"
 #endif
 
 #define SECTION "setup"
@@ -1356,7 +1353,7 @@ readThreeD(ThreeDWidget w)
 		int red, green, blue;
 	} color;
 
-	fp = openIni(w->core.hWnd, DATAFILE);
+	fp = openIni(w->core.hWnd, INIFILE);
 	string = readLine(fp, buffer, SYMBOL);
 	(void) sscanf(string, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
