@@ -1,7 +1,7 @@
 /*
  * @(#)xthreed.c
  *
- * Copyright 1994 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1994 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -644,6 +644,13 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #endif
 #include "pixmaps/64x64/threed.xbm"
 #define DEFINE_XBM (char *) threed_64x64_bits, threed_64x64_width, threed_64x64_height
+#ifdef HAVE_EDITRES
+#ifdef __VMS
+#include <Xmu/Editres.h>
+#else
+#include <X11/Xmu/Editres.h>
+#endif
+#endif
 
 #ifdef HAVE_ATHENA
 static Widget distXSliderLabel, distYSliderLabel, distZSliderLabel;
@@ -1067,7 +1074,7 @@ setSoundCheck(Widget w)
 	XtVaGetValues(threed,
 		XtNsound, &sound, NULL);
 #ifdef HAVE_MOTIF
-	XmToggleButtonSetState(w, sound, False);
+	setToggle(w, sound, False);
 #elif defined(HAVE_ATHENA)
 	menuCheck(topLevel, w, sound);
 #endif
@@ -1191,7 +1198,7 @@ static void initialize(Widget w)
 	XmScaleSetValue(phiChanger, angle.phi);
 	XmScaleSetValue(psiChanger, angle.psi);
 #endif
-	XmToggleButtonSetState(surfaceToggle, surface, True);
+	setToggle(surfaceToggle, surface, False);
 #elif defined(HAVE_ATHENA)
 	if (!surface)
 		XawToggleUnsetCurrent(surfaceToggle);
@@ -1260,7 +1267,7 @@ static void threeDCallback(Widget w, caddr_t clientData,
 		XtVaSetValues(w,
 			XtNsurface, surface, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(surfaceToggle, surface, True);
+		setToggle(surfaceToggle, surface, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(surfaceToggle,
 			XtNstate, surface, NULL);
@@ -1445,7 +1452,14 @@ main(int argc, char **argv)
 #endif
 
 #if defined(HAVE_MOTIF) || defined(HAVE_ATHENA)
+#ifdef __VMS
+	int n;
+	progDsp = strrchr(argv[0], ']');
+	for (n = 0; progDsp[n] != '\0' && progDsp[n] != '.'; n++);
+	progDsp[n] = '\0';
+#else
 	progDsp = strrchr(argv[0], '/');
+#endif
 	if (progDsp != NULL)
 		progDsp++;
 	if (progDsp == NULL)
@@ -1895,9 +1909,13 @@ main(int argc, char **argv)
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(threed),
 		XCreateFontCursor(XtDisplay(threed), XC_hand2));
+#ifdef HAVE_EDITRES
+	XtAddEventHandler(topLevel, (EventMask) 0, TRUE,
+		(XtEventHandler) _XEditResCheckMessages, NULL);
+#endif
 	XtAppMainLoop(appCon);
 
-#ifdef VMS
+#ifdef __VMS
 	return 1;
 #else
 	return 0;
