@@ -1,7 +1,7 @@
 /*
  * @(#)xtriangles.c
  *
- * Copyright 1993 - 2024  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1993 - 2025  David A. Bagley, bagleyd AT verizon.net
  *
  * All rights reserved.
  *
@@ -134,9 +134,9 @@ static TrianglesRec widget;
 
 #ifndef SCOREPATH
 #ifdef UNIXDELIM
-#define SCOREPATH "c:/WINDOWS"
+#define SCOREPATH "C:/ProgramData/wpuzzles"
 #else
-#define SCOREPATH "c:\\WINDOWS"
+#define SCOREPATH "C:\\ProgramData\\wpuzzles"
 #endif
 #endif
 #define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
@@ -170,8 +170,15 @@ static TrianglesRec widget;
 #endif
 #include "pixmaps/64x64/triangles.xbm"
 #define DEFINE_XBM (char *) triangles_64x64_bits, triangles_64x64_width, triangles_64x64_height
+#ifdef HAVE_EDITRES
+#ifdef __VMS
+#include <Xmu/Editres.h>
+#else
+#include <X11/Xmu/Editres.h>
+#endif
+#endif
 #ifndef SCOREPATH
-#ifdef VMS
+#ifdef __VMS
 #define SCOREPATH "SYS$LOGIN:"
 #else
 #define SCOREPATH "/var/games/xpuzzles"
@@ -879,7 +886,7 @@ setSoundCheck(Widget w)
 	XtVaGetValues(puzzle,
 		XtNsound, &sound, NULL);
 #ifdef HAVE_MOTIF
-	XmToggleButtonSetState(w, sound, False);
+	setToggle(w, sound, False);
 #elif defined(HAVE_ATHENA)
 	menuCheck(topLevel, w, sound);
 #endif
@@ -1030,7 +1037,7 @@ Widget w
 			XmNmaximum, sizeY, NULL);
 	XmScaleSetValue(tileYChanger, sizeY);
 #endif
-	XmToggleButtonSetState(cornersToggle, corners, True);
+	setToggle(cornersToggle, corners, False);
 #ifdef ANIMATE
 	{
 		int delay, speed;
@@ -1362,7 +1369,7 @@ puzzleCallback(Widget w, caddr_t clientData,
 		XtVaSetValues(w,
 			XtNcorners, corners, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(cornersToggle, corners, True);
+		setToggle(cornersToggle, corners, False);
 #elif defined(HAVE_ATHENA)
 		XtVaSetValues(cornersToggle,
 			XtNstate, corners, NULL);
@@ -1815,7 +1822,14 @@ main(int argc, char **argv)
 	unsigned int i;
 #endif
 
+#ifdef __VMS
+	int n;
+	progDsp = strrchr(argv[0], ']');
+	for (n = 0; progDsp[n] != '\0' && progDsp[n] != '.'; n++);
+	progDsp[n] = '\0';
+#else
 	progDsp = strrchr(argv[0], '/');
+#endif
 	if (progDsp != NULL)
 		progDsp++;
 	if (progDsp == NULL)
@@ -2264,9 +2278,13 @@ main(int argc, char **argv)
 		ButtonMotionMask | ButtonReleaseMask),
 		GrabModeAsync, GrabModeAsync, XtWindow(puzzle),
 		XCreateFontCursor(XtDisplay(puzzle), XC_hand2));
+#ifdef HAVE_EDITRES
+	XtAddEventHandler(topLevel, (EventMask) 0, TRUE,
+		(XtEventHandler) _XEditResCheckMessages, NULL);
+#endif
 	XtAppMainLoop(appCon);
 
-#ifdef VMS
+#ifdef __VMS
 	return 1;
 #else
 	return 0;
